# **About**
This library can help you program some simple kinematics processes and get some important (maybe) data from it
# **Getting saterted**
## **Installing**
To install phyengine, run following command in command prompt:

```pip install phyengine```

## **Importing**
You can import this like usual library:

```import phyengine```

# **Basic acknowledge**
## **Vectors**
Phyengine can work with 2d vectors. General syntax to create vector object is

```phyengine.Vector(<coordx>, <coordy>)```

For example:

```first = phyengine.Vector(2, 3)```